Recipes
=======

.. toctree::
   :maxdepth: 1

   recipes/csv_files.rst
   recipes/database_to_database.rst
   recipes/database_to_api.rst
   recipes/spatial_etl.rst
   recipes/apache_airflow_integration.rst
